from AccessControl import ClassSecurityInfo
from Acquisition import aq_base
from DateTime import DateTime
from Acquisition import aq_inner, aq_parent, aq_base, aq_chain
from Products.Archetypes.utils import shasattr
from Products.CMFCore.utils import getToolByName
from Products.MailHost.MailHost import MailBase
import zLOG

PATCH_PREFIX = '_monkey_'

__refresh_module__ = 0

def monkeyPatch(originalClass, patchingClass):
    print 'monkeyPatch', originalClass.__name__, patchingClass.__name__
    """Monkey patch original class with attributes from new class
       (Swiped from SpeedPack -- thanks, Christian Heimes!)
    
    * Takes all attributes and methods except __doc__ and __module__ from patching class
    * Safes original attributes as _monkey_name
    * Overwrites/adds these attributes in original class
    """
    for name, newAttr in patchingClass.__dict__.items():
        # don't overwrite doc or module informations
        if name not in ('__doc__', '__module__'):
            # safe the old attribute as __monkey_name if exists
            # __dict__ doesn't show inherited attributes :/
            orig = getattr(originalClass, name, None)
            if orig:
                stored_orig_name = PATCH_PREFIX + name
                stored_orig = getattr(originalClass, stored_orig_name, None)
                # don't double-patch on refresh!
                if stored_orig is None:
                    originalClass.__dict__[stored_orig_name] = orig
            # overwrite or add the new attribute
            originalClass.__dict__[name] = newAttr


class PrintingMailHost:
    
    #
    #   MailHost which prints to output
    #

    security = ClassSecurityInfo()

    security.declarePrivate( '_send' )
    def _send( self, mfrom, mto, messageText ):
        """ Send the message """
        print
        print " ---- sending mail ---- "
        print "From:", mfrom
        print "To:", mto
        print messageText
        print " ---- done ---- "
        print
    
zLOG.LOG('PrintingMailHost', zLOG.WARNING, 
          '\n\n********************\n' 
          'Monkey patching MailHost to print emails to the terminal instead of sending them\n'
          '\n'
          'NO MAIL WILL BE SENT FROM ZOPE AT ALL!\n'
          '\n'
          'Turn off debug mode or remove PrintingMailHost from the Products directory to\n'
          'turn this off.\n'
          '\n********************\n')

monkeyPatch(MailBase, PrintingMailHost)
